@@ -74,7 +74,41 @@ def normalize_image (image):
 
 
     
+def show_im(image, title='No Title', cvTwo=True, bit=8):
+    '''
+    To show image using matplotlib
+    Using Qt5Agg backend to prevent MAC from crashing
+    Image - Standard uint8/16 array
+    Title - Figure title as string
+    cvTwo - cv2 reads images as BGR, thus giving incorrect colour. Default = True, which converts BGR to RGB
+    '''
     
+    # Check if image is color of grayscale
+    # Seek for length of the array shape
+    # If length = 3, image is 3D array/color image
+    # If length = 2, image is 2D array/grayscale image
+    foo = len(image.shape) 
+    
+    # Check bit depth and set pixel value max limit for displaying gray image
+    if image.dtype == 'uint8':
+        pvmax = 255
+    else:
+        pvmax = 2**16-1
+    
+    plt.figure()
+    if foo == 2:
+        plt.imshow(image, cmap=cm.gray, vmin=0, vmax=pvmax)
+        plt.title(title)
+        plt.show()
+    else:
+        if cvTwo == True:
+            plt.imshow(cv2.cvtColor(image, cv2.COLOR_BGR2RGB))
+            plt.title(title)
+            plt.show()   
+        else:
+            plt.imshow(image)
+            plt.title(title)
+            plt.show()    
     
     
     
